==> 2.0.0.tar.gz: xml-dblp/README.md <==
# Projet XML : TP SAX

## Arthur Brandao & Maxence Bacquet - M2 ILI

Programme pour interroger la base de données DBLP au format XML.

## Documentation des commandes

La documentation suivante pars du principe qu'un terminal est ouvert dans le dossier du projet et que nodejs est installé

## Partie 0 - Paramétrage et Déploiement

Le projet est composé de plusieurs programme avec la même base. Pour exécuter les scripts propre à chaque programme il faut utiliser la commande suivante :

```bash
npm start <program> <script>
# Par exemple
npm start coauth test
```

Pour séparer chaque programme en un ensemble de fichier indépendant il faut lancer la commande :

```bash
npm run deploy
```

Un dossier seras crée avec le nom de chaque programme dans le dossier `dist` (si il n'existe pas il seras crée).

Chaque dossier comportera ses sources, son package.json et son README.md.

Le parametrage des différents projets (les scripts, la version, les dépendances, ...) sont paramétrable depuis le fichier deploy.json

## Partie 1 - Recherche des co-auteurs d'un auteur

L'objectif du programme est de trouver les co-auteurs d'un auteur donné. Le programme possède deux fonctions, la première permet de faire un pré-traitement de la base dans un fichier .ppf (Pre Processing File), le second permet d'effectuer la recherche depuis le fichier obtenu suite au pré-traitement.

### Commande de pré-traitement de la base

Cette commande permet de générer un fichier .ppf (si aucune destination n'est indiquée le chemin vers le fichier seras le quivant : `./data/data.ppf`)

La commande est :

```bash
node coauth.js prepare <source> [destination]
```

- `<source>` : correspond au chemin vers la base de données au format xml
- `[destination]` : Le chemin et le nom du fichier .ppf à créer suite au pré-traitement de la base de données (si l'extension n'est pas .pff elle seras automatiquement ajoutée), cet argument est optionel

Une commande npm est aussi disponible, elle est l'équivalent de la commande en dessous d'elle :

```bash
npm run preprocess
# <=>
node coauth.js prepare ./data/dblp.xml ./data/data.ppf
```

### Commande de recherche des co-auteurs

La recherche des co-auteurs ne peut avoir lieu qu'après avoir executé une fois la commande de pré-traitement car elle nécéssite un fichier .ppf pour fonctionner

La commande de base est la suivante :

```bash
node coauth.js
```

Avec cette commande le programme considère que le fichier .ppf est dans `./data/data.ppf`. Le nom de l'auteur dont il faut chercher les co-auteurs seras demandé par le programme dans la console.

La commande admet plusieurs options :

- `-n <string>` ou `--name <string>` ou `--name=<string>` : Pour indiquer le nom de l'auteur pour la recherche
- `-f <source>` ou `--file <string>` ou `--file=<string>` : Pour indiquer le chemin vers le fichier .ppf à utiliser
- `-v` ou `--verbose` : Permet d'afficher plus d'informations dans la console
- `-h` ou `--help` : Affiche l'aide
- `-V` ou `--version` : Affiche la version du programme

Voici quelques exemples avec des options :

```bash
node coauth.js -n "Fabien Delorme"
node coauth.js --name="Anne-Cécile Caron" -f "./data/data.ppf"
node coauth.js --name "Francis Bossut" --file "./tmp/coauth.ppf" -v
```

Le retour du programme sans l'option verbose est similaire au retour du programme de reference fournit. Attention la recherche sur le nom est sensible à la casse.

Il existe aussi une commande npm pour executer le programme, elle est équivalente à la commande en dessous d'elle :

```bash
npm start
# <=>
node coauth.js -f "./data/data.ppf"
```

### Commande d'éxecution du pré-traitement puis de la recherche

En ajoutant l'option `-p <source>` ou `--process <source>` il est possible d'effectuer le pré-traitement puis une recherche des co-auteurs. `<source>` correspond au chemin vers le fichier de base de données en XML. De plus l'option process est utilisable avec les autres options du programme, la seul différence est que l'option file sert en plus à indiquer le chemin pour créer le fichier de pré-traitement (fichier qui seras utilisé pour la recherche).

Voici quelques exemples expliqués de la commande avec l'option process :

```bash
# Lance le pré-traitement sur le fichier ./data/dblp.xml, génere le fichier ./data/data.ppf et le nom de l'auteur pour la recherche est demandé dans la console
node coauth.js --process ./data/dblp.xml

# Lance le pré-traitement sur le fichier ./data/dblp.xml, génere le fichier ./data/data.ppf et fait la recherche sur Fabien Delorme
node coauth.js -p ./data/dblp.xml -n "Fabien Delorme"

# Lance le pré-traitement sur le fichier ./data/dblp.xml, génere le fichier ./tmp/coauth.ppf et fait la recherche sur Fabien Delorme
node coauth.js -p ./data/dblp.xml -n "Fabien Delorme" -f ./tmp/coauth.ppf
```

Une commande avec npm est aussi disponible, elle est équivalente à la commande en dessous d'elle. Le nom de l'auteur pour la recherche est demandé dans la console lors de l'execution.

```bash
npm run process
# <=>
node coauth.js --process ./data/dblp.xml
```

### Temps d'exécution

Les temps d'executions des commandes sur nos PC sont de :

|                 | Ubuntu (PC Fac) | Kubuntu                | Kde Neon (I7-8550U)   |
| --------------- | --------------- | ---------------------- | --------------------- |
| **Référence**   |                 | ?                      | environ 2 minutes 30  |
| **Préparation** |                 | environ 2 minutes      | environ 1 minute 45   |
| **Recherche**   |                 | entre 5 et 10 secondes | entre 3 et 5 secondes |

## Partie 2

blabla

==> 2.0.1.tar.gz: xml-dblp/README.md <==
# Projet XML : TP SAX

## Arthur Brandao & Maxence Bacquet - M2 ILI

Programme pour interroger la base de données DBLP au format XML.

## Documentation des commandes

La documentation suivante pars du principe qu'un terminal est ouvert dans le dossier du projet et que nodejs est installé

## Partie 0 - Paramétrage et Déploiement

Le projet est composé de plusieurs programmes avec la même base. Pour exécuter les scripts propres à chaque programme il faut utiliser la commande suivante :

```bash
npm start <program> <script>
# Par exemple
npm start coauth test
```

Pour séparer chaque programme en un ensemble de fichier indépendant il faut lancer la commande :

```bash
npm run deploy
```

Un dossier sera créé avec le nom de chaque programme dans le dossier `dist` (si il n'existe pas il sera créé).

Chaque dossier comportera ses sources, son package.json et son README.md.

Le paramétrage des différents projets (les scripts, la version, les dépendances, ...) sont paramétrables depuis le fichier deploy.json

## Partie 1 - Recherche des co-auteurs d'un auteur

L'objectif du programme est de trouver les co-auteurs d'un auteur donné. Le programme possède deux fonctions, la première permet de faire un pré-traitement de la base dans un fichier .ppf (Pre Processing File), le second permet d'effectuer la recherche depuis le fichier obtenu suite au pré-traitement.

### Commande de pré-traitement de la base

Cette commande permet de générer un fichier .ppf (si aucune destination n'est indiquée le chemin vers le fichier seras le quivant : `./data/data.ppf`)

La commande est :

```bash
node coauth.js prepare <source> [destination]
```

- `<source>` : correspond au chemin vers la base de données au format xml
- `[destination]` : Le chemin et le nom du fichier .ppf à créer suite au pré-traitement de la base de données (si l'extension n'est pas .pff elle seras automatiquement ajoutée), cet argument est optionel

Une commande npm est aussi disponible, elle est l'équivalent de la commande en dessous d'elle :

```bash
npm run preprocess
# <=>
node coauth.js prepare ./data/dblp.xml ./data/data.ppf
```

### Commande de recherche des co-auteurs

La recherche des co-auteurs ne peut avoir lieu qu'après avoir executé une fois la commande de pré-traitement car elle nécéssite un fichier .ppf pour fonctionner

La commande de base est la suivante :

```bash
node coauth.js
```

Avec cette commande le programme considère que le fichier .ppf est dans `./data/data.ppf`. Le nom de l'auteur dont il faut chercher les co-auteurs seras demandé par le programme dans la console.

La commande admet plusieurs options :

- `-n <string>` ou `--name <string>` ou `--name=<string>` : Pour indiquer le nom de l'auteur pour la recherche
- `-f <source>` ou `--file <string>` ou `--file=<string>` : Pour indiquer le chemin vers le fichier .ppf à utiliser
- `-v` ou `--verbose` : Permet d'afficher plus d'informations dans la console
- `-h` ou `--help` : Affiche l'aide
- `-V` ou `--version` : Affiche la version du programme

Voici quelques exemples avec des options :

```bash
node coauth.js -n "Fabien Delorme"
node coauth.js --name="Anne-Cécile Caron" -f "./data/data.ppf"
node coauth.js --name "Francis Bossut" --file "./tmp/coauth.ppf" -v
```

Le retour du programme sans l'option verbose est similaire au retour du programme de reference fournit. Attention la recherche sur le nom est sensible à la casse.

Il existe aussi une commande npm pour executer le programme, elle est équivalente à la commande en dessous d'elle :

```bash
npm start
# <=>
node coauth.js -f "./data/data.ppf"
```

### Commande d'éxecution du pré-traitement puis de la recherche

En ajoutant l'option `-p <source>` ou `--process <source>` il est possible d'effectuer le pré-traitement puis une recherche des co-auteurs. `<source>` correspond au chemin vers le fichier de base de données en XML. De plus l'option process est utilisable avec les autres options du programme, la seul différence est que l'option file sert en plus à indiquer le chemin pour créer le fichier de pré-traitement (fichier qui seras utilisé pour la recherche).

Voici quelques exemples expliqués de la commande avec l'option process :

```bash
# Lance le pré-traitement sur le fichier ./data/dblp.xml, génere le fichier ./data/data.ppf et le nom de l'auteur pour la recherche est demandé dans la console
node coauth.js --process ./data/dblp.xml

# Lance le pré-traitement sur le fichier ./data/dblp.xml, génere le fichier ./data/data.ppf et fait la recherche sur Fabien Delorme
node coauth.js -p ./data/dblp.xml -n "Fabien Delorme"

# Lance le pré-traitement sur le fichier ./data/dblp.xml, génere le fichier ./tmp/coauth.ppf et fait la recherche sur Fabien Delorme
node coauth.js -p ./data/dblp.xml -n "Fabien Delorme" -f ./tmp/coauth.ppf
```

Une commande avec npm est aussi disponible, elle est équivalente à la commande en dessous d'elle. Le nom de l'auteur pour la recherche est demandé dans la console lors de l'execution.

```bash
npm run process
# <=>
node coauth.js --process ./data/dblp.xml
```

### Temps d'exécution

Les temps d'executions des commandes sur nos PC sont de :

|                 | Ubuntu (PC Fac) | Kubuntu (I5-7300HQ)    | Kde Neon (I7-8550U)   |
| --------------- | --------------- | ---------------------- | --------------------- |
| **Référence**   |                 | ?                      | environ 2 minutes 30  |
| **Préparation** |                 | environ 2 minutes      | environ 1 minute 45   |
| **Recherche**   |                 | entre 5 et 10 secondes | entre 3 et 5 secondes |

## Partie 2 - Extraction de données d'un auteur

L'objectif du programme est de générer un document XML avec les infos extraites des articles et des inproceedings d'un auteur donné dans la base de données DBLP au format XML. Le document comporte aussi une section avec tous les co-auteurs de l'auteur donné dans les données extraites.

### Commande d'extraction des données

La commande pour extraire les données de la base est la suivante (en dessous son équivalent avec npm) : 

```bash
node extract.js
# <=>
npm start
```

Par défaut le programme va chercher le fichier XML de la base dans le dossier data avec le nom dblp.xml et créer un fichier extract.xml dans ce même dossier. Le nom de l'auteur sera demandé dans la console avant de lancer la recherche.

Le programme possède plusieurs options :

- `-n <string>` ou `--name <string>` ou `--name=<string>` : Pour indiquer le nom de l'auteur pour la recherche
- `-f <source>` ou `--file <string>` ou `--file=<string>` : Pour indiquer le chemin vers le fichier de la base (en XML)
- `-o <source>` ou `--output <string>` ou `--output=<string>` : Pour indiquer le chemin pour la création du fichier contenant les données de l'extraction (en XML)
- `-v` ou `--verbose` : Permet d'afficher plus d'informations dans la console
- `-h` ou `--help` : Affiche l'aide
- `-V` ou `--version` : Affiche la version du programme

Voici quelques exemples et leur explication de la commande avec ces options :

```bash
# Recherche les informations sur Fabien Delorme dans la base ./data/dblp.xml et extrait les informations dans ./data/extract.xml
node extract.js --name "Fabien Delorme"

# Recherche les informations sur Fabien Delorme dans la base ./data/dblp.xml et extrait les informations dans ./data/fabienDelorme.xml
node extract.js --name="Fabien Delorme" --output "./data/fabienDelorme.xml"

# Recherche les informations sur Fabien Delorme dans la base ./data/base.xml et extrait les informations dans ./data/extract.xml
node extract.js -n "Fabien Delorme" -o "./data/fabienDelorme.xml" -f "./data/base.xml"

# Recherche les informations sur Fabien Delorme dans la base ./data/base.xml et extrait les informations dans ./data/extract.xml et affiche des informations sur l'exécution
node extract.js -n "Fabien Delorme" -o "./data/fabienDelorme.xml" -f "./data/base.xml" -v
```



### Temps d'exécution

|                | Ubuntu (PC Fac) | Kubuntu (I5-7300HQ) | KDE Neon (I7-8550U)     |
| -------------- | --------------- | ------------------- | ----------------------- |
| **Extraction** |                 |                     | entre 45 et 50 secondes |
